{% extends "base.html" %}

{% block title %}
FeedMe
{% endblock title %}

{% block styles %}
{{ block.super }}
<link href="{{ STATIC_URL }}css/feedme.css" rel="stylesheet">
{% endblock styles %}

{% load admin_tags %}

{% block submenu %}
{% include "feedme/nav.html" %}
{% endblock submenu %}

{% block content %}

<section id="feedme-admin">
    <div class="container">
        <div class="page-header clearfix">
            <div class="row">
                <div class="col-md-12">
                    <h2>{{ form.name|title }}</h2>
                    <h3>HER KAN DU OPPPPPDATERE BRUKERES BALANSE</h3>
                    <!--{% include "messages.html" %}-->
                    {% if user or group %}
                      <form action="" method="POST">
                        {% csrf_token %}
                        {{ form.errors }}
                        {{ form }}
                        <input type="submit" class="btn btn-primary" value="Deposit">
                      </form>
                    {% endif %}
                </div>
            </div>
        </div>
    </div>
</section>
{% endblock content %}
